==> scm-api-2.2.2-sources.jar: jenkins/scm/impl/trait/Messages.java <==
// CHECKSTYLE:OFF

package jenkins.scm.impl.trait;

import org.jvnet.localizer.Localizable;
import org.jvnet.localizer.ResourceBundleHolder;


/**
 * Generated localization support class.
 * 
 */
@SuppressWarnings({
    "",
    "PMD",
    "all"
})
public class Messages {

    /**
     * The resource bundle reference
     * 
     */
    private final static ResourceBundleHolder holder = ResourceBundleHolder.get(Messages.class);

    /**
     * Key {@code RegexSCMHeadFilterTrait.DisplayName}: {@code Filter by name
     * (with regular expression)}.
     * 
     * @return
     *     {@code Filter by name (with regular expression)}
     */
    public static String RegexSCMHeadFilterTrait_DisplayName() {
        return holder.format("RegexSCMHeadFilterTrait.DisplayName");
    }

    /**
     * Key {@code RegexSCMHeadFilterTrait.DisplayName}: {@code Filter by name
     * (with regular expression)}.
     * 
     * @return
     *     {@code Filter by name (with regular expression)}
     */
    public static Localizable _RegexSCMHeadFilterTrait_DisplayName() {
        return new Localizable(holder, "RegexSCMHeadFilterTrait.DisplayName");
    }

    /**
     * Key {@code RegexSCMSourceFilterTrait.DisplayName}: {@code Filter by
     * name (with regular expression)}.
     * 
     * @return
     *     {@code Filter by name (with regular expression)}
     */
    public static String RegexSCMSourceFilterTrait_DisplayName() {
        return holder.format("RegexSCMSourceFilterTrait.DisplayName");
    }

    /**
     * Key {@code RegexSCMSourceFilterTrait.DisplayName}: {@code Filter by
     * name (with regular expression)}.
     * 
     * @return
     *     {@code Filter by name (with regular expression)}
     */
    public static Localizable _RegexSCMSourceFilterTrait_DisplayName() {
        return new Localizable(holder, "RegexSCMSourceFilterTrait.DisplayName");
    }

    /**
     * Key {@code WildcardSCMSourceFilterTrait.DisplayName}: {@code Filter by
     * name (with wildcards)}.
     * 
     * @return
     *     {@code Filter by name (with wildcards)}
     */
    public static String WildcardSCMSourceFilterTrait_DisplayName() {
        return holder.format("WildcardSCMSourceFilterTrait.DisplayName");
    }

    /**
     * Key {@code WildcardSCMSourceFilterTrait.DisplayName}: {@code Filter by
     * name (with wildcards)}.
     * 
     * @return
     *     {@code Filter by name (with wildcards)}
     */
    public static Localizable _WildcardSCMSourceFilterTrait_DisplayName() {
        return new Localizable(holder, "WildcardSCMSourceFilterTrait.DisplayName");
    }

    /**
     * Key {@code WildcardSCMHeadFilterTrait.DisplayName}: {@code Filter by
     * name (with wildcards)}.
     * 
     * @return
     *     {@code Filter by name (with wildcards)}
     */
    public static String WildcardSCMHeadFilterTrait_DisplayName() {
        return holder.format("WildcardSCMHeadFilterTrait.DisplayName");
    }

    /**
     * Key {@code WildcardSCMHeadFilterTrait.DisplayName}: {@code Filter by
     * name (with wildcards)}.
     * 
     * @return
     *     {@code Filter by name (with wildcards)}
     */
    public static Localizable _WildcardSCMHeadFilterTrait_DisplayName() {
        return new Localizable(holder, "WildcardSCMHeadFilterTrait.DisplayName");
    }

}

==> scm-api-2.4.1-sources.jar: jenkins/scm/impl/trait/Messages.java <==
// CHECKSTYLE:OFF

package jenkins.scm.impl.trait;

import org.jvnet.localizer.Localizable;
import org.jvnet.localizer.ResourceBundleHolder;
import org.kohsuke.accmod.Restricted;


/**
 * Generated localization support class.
 * 
 */
@SuppressWarnings({
    "",
    "PMD",
    "all"
})
@Restricted(org.kohsuke.accmod.restrictions.NoExternalUse.class)
public class Messages {

    /**
     * The resource bundle reference
     * 
     */
    private final static ResourceBundleHolder holder = ResourceBundleHolder.get(Messages.class);

    /**
     * Key {@code RegexSCMHeadFilterTrait.DisplayName}: {@code Filter by name
     * (with regular expression)}.
     * 
     * @return
     *     {@code Filter by name (with regular expression)}
     */
    public static String RegexSCMHeadFilterTrait_DisplayName() {
        return holder.format("RegexSCMHeadFilterTrait.DisplayName");
    }

    /**
     * Key {@code RegexSCMHeadFilterTrait.DisplayName}: {@code Filter by name
     * (with regular expression)}.
     * 
     * @return
     *     {@code Filter by name (with regular expression)}
     */
    public static Localizable _RegexSCMHeadFilterTrait_DisplayName() {
        return new Localizable(holder, "RegexSCMHeadFilterTrait.DisplayName");
    }

    /**
     * Key {@code RegexSCMSourceFilterTrait.DisplayName}: {@code Filter by
     * name (with regular expression)}.
     * 
     * @return
     *     {@code Filter by name (with regular expression)}
     */
    public static String RegexSCMSourceFilterTrait_DisplayName() {
        return holder.format("RegexSCMSourceFilterTrait.DisplayName");
    }

    /**
     * Key {@code RegexSCMSourceFilterTrait.DisplayName}: {@code Filter by
     * name (with regular expression)}.
     * 
     * @return
     *     {@code Filter by name (with regular expression)}
     */
    public static Localizable _RegexSCMSourceFilterTrait_DisplayName() {
        return new Localizable(holder, "RegexSCMSourceFilterTrait.DisplayName");
    }

    /**
     * Key {@code WildcardSCMSourceFilterTrait.DisplayName}: {@code Filter by
     * name (with wildcards)}.
     * 
     * @return
     *     {@code Filter by name (with wildcards)}
     */
    public static String WildcardSCMSourceFilterTrait_DisplayName() {
        return holder.format("WildcardSCMSourceFilterTrait.DisplayName");
    }

    /**
     * Key {@code WildcardSCMSourceFilterTrait.DisplayName}: {@code Filter by
     * name (with wildcards)}.
     * 
     * @return
     *     {@code Filter by name (with wildcards)}
     */
    public static Localizable _WildcardSCMSourceFilterTrait_DisplayName() {
        return new Localizable(holder, "WildcardSCMSourceFilterTrait.DisplayName");
    }

    /**
     * Key {@code WildcardSCMHeadFilterTrait.DisplayName}: {@code Filter by
     * name (with wildcards)}.
     * 
     * @return
     *     {@code Filter by name (with wildcards)}
     */
    public static String WildcardSCMHeadFilterTrait_DisplayName() {
        return holder.format("WildcardSCMHeadFilterTrait.DisplayName");
    }

    /**
     * Key {@code WildcardSCMHeadFilterTrait.DisplayName}: {@code Filter by
     * name (with wildcards)}.
     * 
     * @return
     *     {@code Filter by name (with wildcards)}
     */
    public static Localizable _WildcardSCMHeadFilterTrait_DisplayName() {
        return new Localizable(holder, "WildcardSCMHeadFilterTrait.DisplayName");
    }

}
